"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLoggerTool = void 0;
const uuid_1 = require("uuid");
const path = require("path");
const nestjs_context_1 = require("nestjs-context");
const services_1 = require("../services");
const config_1 = require("../config");
const type_guards_1 = require("../type-guards");
const createLoggerTool = (configOrApp = {}, contextName = process.argv[1]
    ? path.basename(process.argv[1], path.extname(process.argv[1]))
    : path.basename(__filename)) => {
    let logger;
    try {
        let config, context;
        if (type_guards_1.isNestApplication(configOrApp)) {
            config = configOrApp.get(config_1.LoggerConfig);
            context = configOrApp.get(nestjs_context_1.Context);
        }
        else {
            const config = new config_1.LoggerConfig(configOrApp);
            context = new nestjs_context_1.Context(`System-Logger-${uuid_1.v4()}`, config.context, {});
        }
        logger = new services_1.Logger(config, context);
        logger.setContext(contextName);
        logger.debug(`Created ${services_1.Logger.name} with context ${contextName} and config ${JSON.stringify(config)}`);
    }
    catch (e) {
        logger = new services_1.Logger();
        logger.setContext(contextName);
        logger.warn(`Could not create ${services_1.Logger.name} into the given context. Reason: ${e.toString()}`);
    }
    logger.setContext(contextName);
    return logger;
};
exports.createLoggerTool = createLoggerTool;
